﻿#region Using Statements
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;
#endregion

namespace FoodFight
{
    public class ModelEntity
    {
        private Model _model;
        public Vector3 Position { get; set; }
        public Vector3 Rotation { get; set; }
        public Vector3 Scale { get; set; }

        private BoundingSphere _coll;

        public BoundingSphere CollisionSphere
        {
            get { return _coll; }
        }

        public ModelEntity(Model modelToLoad, Vector3 position, Vector3 scale, float boundingRadius)
        {
            _model = modelToLoad;
            this.Position = position;
            this.Scale = scale;
            _coll = new BoundingSphere(this.Position, boundingRadius);
        }

        public void Update()
        {
            _coll = new BoundingSphere(this.Position, _coll.Radius);
        }

        public void Draw(PlayerCamera cam)
        {
            Matrix[] transforms = new Matrix[_model.Bones.Count];
            _model.CopyAbsoluteBoneTransformsTo(transforms);

            foreach(ModelMesh mesh in _model.Meshes) {
                foreach (BasicEffect effect in mesh.Effects)
                {
                    effect.EnableDefaultLighting();
                    effect.PreferPerPixelLighting = true;
                    effect.World = transforms[mesh.ParentBone.Index] * Matrix.CreateScale(this.Scale)
                        * Matrix.CreateRotationX(this.Rotation.X) * Matrix.CreateRotationY(this.Rotation.Y) * Matrix.CreateRotationZ(this.Rotation.Z)
                        * Matrix.CreateTranslation(this.Position);
                    effect.View = Matrix.CreateLookAt(cam.Position, cam.LookAt, Vector3.Up);
                    effect.Projection = Matrix.CreatePerspectiveFieldOfView(MathHelper.ToRadians(45.0f), FoodFight.AspectRatio, 1.0f, 100000.0f);
                }

                mesh.Draw();
            }
        }
    }
}
