﻿#region Using Statements
using System;
using System.IO;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Storage;
using Microsoft.Xna.Framework.Graphics;
using FoodFight._2D;
using Microsoft.Xna.Framework.Content;
#endregion

namespace FoodFight
{
    public class ContentLoadUtility
    {
        public static void LoadContent(ContentManager content, String fileToLoad, ref List<Drawable> drawables)
        {
            try
            {
                using (StreamReader sr = new StreamReader(StorageContainer.TitleLocation + "\\Content\\" + fileToLoad))
                {
                    String line;

                    while ((line = sr.ReadLine()) != null)
                    {
                        line = line.Replace(" ", "");
                        String[] temp = line.Split(',');

                        if (temp[0].StartsWith("'") != true && line.Replace(" ", "") != "")
                        {
                            if (temp[0].ToLower() == "spritesheet")
                            {
                                LoadSpriteSheet(content, ref drawables, temp[1]);
                            }
                            else if (temp[0].ToLower() == "font")
                            {
                                LoadFont(content, ref drawables, temp);
                            }
                            else if (temp[0].ToLower() == "scorefont")
                            {
                                LoadScoreFont(content, ref drawables, temp);
                            }
                            else// if (temp[0].ToLower() == "sprite")
                            {
                                LoadSprite(content, ref drawables, temp);
                            }
                        }
                    }
                }
            }
            catch (Exception e)
            {
                //QUIT!
                throw new Exception("Error Parsing Load File - Shutting Down");
            }
        }

        public static void LoadMenuContent(ContentManager content, String fileToLoad, ref List<MenuItem> drawables)
        {
            try
            {
                using (StreamReader sr = new StreamReader(StorageContainer.TitleLocation + "\\Content\\" + fileToLoad))
                {
                    String line;

                    while ((line = sr.ReadLine()) != null)
                    {
                        line = line.Replace(" ", "");
                        String[] temp = line.Split(',');

                        if (temp[0].StartsWith("'") != true && line.Replace(" ", "") != "")
                        {
                            if (temp[0].ToLower() == "rotatingarrowwidget")
                            {
                                LoadRotatingArrowWidget(content, ref drawables, temp);
                            }
                            else if (temp[0].ToLower() == "newgameoption")
                            {
                                LoadNewGameOption(content, ref drawables, temp);
                            }
                            else if (temp[0].ToLower() == "menubackground")
                            {
                                LoadMenuBackground(content, ref drawables, temp);
                            }
                            else
                            {
                                LoadExitGameOption(content, ref drawables, temp);
                            }
                        }
                    }
                }
            }
            catch (Exception e)
            {
                //QUIT!
                throw new Exception("Error Parsing Load File - Shutting Down");
            }
        }

        private static void LoadSprite(ContentManager content, ref List<Drawable> drawables, String[] spriteData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            Texture2D texture = content.Load<Texture2D>(spriteData[1]);

            if (spriteData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (spriteData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(spriteData[3].Substring(1));
            else
                pos.X = float.Parse(spriteData[3]);

            if (spriteData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (spriteData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("T"))
            {
                if (spriteData[4].StartsWith("TBG"))
                    pos.Y = texture.Height / 2 + float.Parse(spriteData[4].Substring(3));
                else
                    pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(spriteData[4].Substring(1));
            }
            else
                pos.Y = float.Parse(spriteData[4]);

            bool vis = false;

            if (spriteData[9].ToLower() == "true")
                vis = true;

            Vector2 boundingSize = new Vector2(0.0f, 0.0f);

            if (spriteData[12].ToLower() == "width")
                boundingSize.X = texture.Width;
            else
                boundingSize.X = float.Parse(spriteData[12]);

            if (spriteData[13].ToLower() == "height")
                boundingSize.Y = texture.Height;
            else
                boundingSize.Y = float.Parse(spriteData[13]);

            SpriteEntity s = new SpriteEntity(texture,
                new Rectangle(Convert.ToInt32(spriteData[10]), Convert.ToInt32(spriteData[11]), Convert.ToInt32(boundingSize.X), Convert.ToInt32(boundingSize.Y)),
                pos, MathHelper.ToRadians(Convert.ToInt32(spriteData[5])),
                new Vector2(float.Parse(spriteData[6]), float.Parse(spriteData[7])), vis, float.Parse(spriteData[8]));

                /*Layer = float.Parse(spriteData[8]),
                Visible = vis,
                SourceRect = new Rectangle(Convert.ToInt32(spriteData[10]), Convert.ToInt32(spriteData[11]),
                    Convert.ToInt32(boundingSize.X), Convert.ToInt32(boundingSize.Y)),*/

            drawables.Add(s);
        }

        private static void LoadRotatingArrowWidget(ContentManager content, ref List<MenuItem> drawables, String[] spriteData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            Texture2D texture = content.Load<Texture2D>(spriteData[1]);

            if (spriteData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (spriteData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(spriteData[3].Substring(1));
            else
                pos.X = float.Parse(spriteData[3]);

            if (spriteData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (spriteData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("T"))
            {
                if (spriteData[4].StartsWith("TBG"))
                    pos.Y = texture.Height / 2 + float.Parse(spriteData[4].Substring(3));
                else
                    pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(spriteData[4].Substring(1));
            }
            else
                pos.Y = float.Parse(spriteData[4]);

            bool vis = false;

            if (spriteData[9].ToLower() == "true")
                vis = true;

            Vector2 boundingSize = new Vector2(0.0f, 0.0f);

            if (spriteData[12].ToLower() == "width")
                boundingSize.X = texture.Width;
            else
                boundingSize.X = float.Parse(spriteData[12]);

            if (spriteData[13].ToLower() == "height")
                boundingSize.Y = texture.Height;
            else
                boundingSize.Y = float.Parse(spriteData[13]);

            RotatingArrowWidget s = new RotatingArrowWidget(new SpriteEntity(texture,
                new Rectangle(Convert.ToInt32(spriteData[10]), Convert.ToInt32(spriteData[11]), Convert.ToInt32(boundingSize.X), Convert.ToInt32(boundingSize.Y)),
                pos, MathHelper.ToRadians(Convert.ToInt32(spriteData[5])),
                new Vector2(float.Parse(spriteData[6]), float.Parse(spriteData[7])), vis, float.Parse(spriteData[8])));

            drawables.Add(s);
        }

        private static void LoadNewGameOption(ContentManager content, ref List<MenuItem> drawables, String[] spriteData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            Texture2D texture = content.Load<Texture2D>(spriteData[1]);

            if (spriteData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (spriteData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(spriteData[3].Substring(1));
            else
                pos.X = float.Parse(spriteData[3]);

            if (spriteData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (spriteData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("T"))
            {
                if (spriteData[4].StartsWith("TBG"))
                    pos.Y = texture.Height / 2 + float.Parse(spriteData[4].Substring(3));
                else
                    pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(spriteData[4].Substring(1));
            }
            else
                pos.Y = float.Parse(spriteData[4]);

            bool vis = false;

            if (spriteData[9].ToLower() == "true")
                vis = true;

            Vector2 boundingSize = new Vector2(0.0f, 0.0f);

            if (spriteData[12].ToLower() == "width")
                boundingSize.X = texture.Width;
            else
                boundingSize.X = float.Parse(spriteData[12]);

            if (spriteData[13].ToLower() == "height")
                boundingSize.Y = texture.Height;
            else
                boundingSize.Y = float.Parse(spriteData[13]);

            NewGameOption s = new NewGameOption(new SpriteEntity(texture,
                new Rectangle(Convert.ToInt32(spriteData[10]), Convert.ToInt32(spriteData[11]), Convert.ToInt32(boundingSize.X), Convert.ToInt32(boundingSize.Y)),
                pos, MathHelper.ToRadians(Convert.ToInt32(spriteData[5])),
                new Vector2(float.Parse(spriteData[6]), float.Parse(spriteData[7])), vis, float.Parse(spriteData[8])));

            drawables.Add(s);
        }

        private static void LoadMenuBackground(ContentManager content, ref List<MenuItem> drawables, String[] spriteData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            Texture2D texture = content.Load<Texture2D>(spriteData[1]);

            if (spriteData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (spriteData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(spriteData[3].Substring(1));
            else
                pos.X = float.Parse(spriteData[3]);

            if (spriteData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (spriteData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("T"))
            {
                if (spriteData[4].StartsWith("TBG"))
                    pos.Y = texture.Height / 2 + float.Parse(spriteData[4].Substring(3));
                else
                    pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(spriteData[4].Substring(1));
            }
            else
                pos.Y = float.Parse(spriteData[4]);

            bool vis = false;

            if (spriteData[9].ToLower() == "true")
                vis = true;

            Vector2 boundingSize = new Vector2(0.0f, 0.0f);

            if (spriteData[12].ToLower() == "width")
                boundingSize.X = texture.Width;
            else
                boundingSize.X = float.Parse(spriteData[12]);

            if (spriteData[13].ToLower() == "height")
                boundingSize.Y = texture.Height;
            else
                boundingSize.Y = float.Parse(spriteData[13]);

            MenuBackground s = new MenuBackground(new SpriteEntity(texture,
                new Rectangle(Convert.ToInt32(spriteData[10]), Convert.ToInt32(spriteData[11]), Convert.ToInt32(boundingSize.X), Convert.ToInt32(boundingSize.Y)),
                pos, MathHelper.ToRadians(Convert.ToInt32(spriteData[5])),
                new Vector2(float.Parse(spriteData[6]), float.Parse(spriteData[7])), vis, float.Parse(spriteData[8])));

            drawables.Add(s);
        }

        private static void LoadExitGameOption(ContentManager content, ref List<MenuItem> drawables, String[] spriteData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            Texture2D texture = content.Load<Texture2D>(spriteData[1]);

            if (spriteData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (spriteData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(spriteData[3].Substring(1));
            else if (spriteData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(spriteData[3].Substring(1));
            else
                pos.X = float.Parse(spriteData[3]);

            if (spriteData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (spriteData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(spriteData[4].Substring(1));
            else if (spriteData[4].StartsWith("T"))
            {
                if (spriteData[4].StartsWith("TBG"))
                    pos.Y = texture.Height / 2 + float.Parse(spriteData[4].Substring(3));
                else
                    pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(spriteData[4].Substring(1));
            }
            else
                pos.Y = float.Parse(spriteData[4]);

            bool vis = false;

            if (spriteData[9].ToLower() == "true")
                vis = true;

            Vector2 boundingSize = new Vector2(0.0f, 0.0f);

            if (spriteData[12].ToLower() == "width")
                boundingSize.X = texture.Width;
            else
                boundingSize.X = float.Parse(spriteData[12]);

            if (spriteData[13].ToLower() == "height")
                boundingSize.Y = texture.Height;
            else
                boundingSize.Y = float.Parse(spriteData[13]);

            ExitGameOption s = new ExitGameOption(new SpriteEntity(texture,
                new Rectangle(Convert.ToInt32(spriteData[10]), Convert.ToInt32(spriteData[11]), Convert.ToInt32(boundingSize.X), Convert.ToInt32(boundingSize.Y)),
                pos, MathHelper.ToRadians(Convert.ToInt32(spriteData[5])),
                new Vector2(float.Parse(spriteData[6]), float.Parse(spriteData[7])), vis, float.Parse(spriteData[8])));

            drawables.Add(s);
        }

        private static void LoadFont(ContentManager content, ref List<Drawable> drawables, String[] fontData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            if (fontData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (fontData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(fontData[3].Substring(1));
            else if (fontData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(fontData[3].Substring(1));
            else if (fontData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(fontData[3].Substring(1));
            else
                pos.X = float.Parse(fontData[3]);

            if (fontData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (fontData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(fontData[4].Substring(1));
            else if (fontData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(fontData[4].Substring(1));
            else if (fontData[4].StartsWith("T"))
                pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(fontData[4].Substring(1));
            else
                pos.Y = float.Parse(fontData[4]);

            bool vis = false;

            if (fontData[9].ToLower() == "true")
                vis = true;

            String tempText = fontData[2];

            FontEntity f = new FontEntity(content.Load<SpriteFont>("Fonts\\TimesNewRoman"), tempText, pos, Convert.ToInt32(fontData[5]),
                new Vector2(float.Parse(fontData[6]), float.Parse(fontData[7])));

                /*ResourceName = fontData[1],
                FontText = tempText,
                FontType = fonts.LoadedFonts[Convert.ToInt32(fontData[10])],
                Layer = float.Parse(fontData[8]),
                Visible = vis*/

            drawables.Add(f);
        }

        private static void LoadScoreFont(ContentManager content, ref List<Drawable> drawables, String[] fontData)
        {
            Vector2 pos = new Vector2(0.0f, 0.0f);

            if (fontData[3].ToLower() == "center")
                pos.X = FoodFight.SCREEN_SAFE.Center.X;
            else if (fontData[3].StartsWith("C"))
                pos.X = FoodFight.SCREEN_SAFE.Center.X + float.Parse(fontData[3].Substring(1));
            else if (fontData[3].StartsWith("L"))
                pos.X = FoodFight.SCREEN_SAFE.Left + float.Parse(fontData[3].Substring(1));
            else if (fontData[3].StartsWith("R"))
                pos.X = FoodFight.SCREEN_SAFE.Right - float.Parse(fontData[3].Substring(1));
            else
                pos.X = float.Parse(fontData[3]);

            if (fontData[4].ToLower() == "center")
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y;
            else if (fontData[4].StartsWith("C"))
                pos.Y = FoodFight.SCREEN_SAFE.Center.Y + float.Parse(fontData[4].Substring(1));
            else if (fontData[4].StartsWith("B"))
                pos.Y = FoodFight.SCREEN_SAFE.Bottom - float.Parse(fontData[4].Substring(1));
            else if (fontData[4].StartsWith("T"))
                pos.Y = FoodFight.SCREEN_SAFE.Top + float.Parse(fontData[4].Substring(1));
            else
                pos.Y = float.Parse(fontData[4]);

            bool vis = false;

            if (fontData[9].ToLower() == "true")
                vis = true;

            String tempText = fontData[2];

            ScoreFont f = new ScoreFont(content.Load<SpriteFont>("Fonts\\TimesNewRoman"), tempText, pos, Convert.ToInt32(fontData[5]),
                new Vector2(float.Parse(fontData[6]), float.Parse(fontData[7])));

            /*ResourceName = fontData[1],
            FontText = tempText,
            FontType = fonts.LoadedFonts[Convert.ToInt32(fontData[10])],
            Layer = float.Parse(fontData[8]),
            Visible = vis*/

            drawables.Add(f);
        }

        private static void LoadSpriteSheet(ContentManager content, ref List<Drawable> drawables, String location)
        {
            Texture2D texture = content.Load<Texture2D>(StorageContainer.TitleLocation + "\\Content\\" + location);
            SpriteEntity s = new SpriteEntity(texture,
                new Rectangle(0, 0, texture.Width, texture.Height),
                Vector2.Zero, 0.0f, Vector2.One, false, 0.0f);
            drawables.Add(s);
        }
    }
}