﻿#region Using Statements
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using FoodFight._2D;
using System.Collections.Generic;
using Microsoft.Xna.Framework.Input;
using System;
#endregion

namespace FoodFight
{
    public struct KeyBinding
    {
        public KeyboardState boardState;
        public MouseState mouseState;
    }

    public class Level1
    {
        private List<Enemy> enemies;
        private ModelEntity ground;

        private List<Drawable> hudEntities;
        private Random rand;

        public List<Enemy> Enemies
        {
            get { return enemies; }
        }

        public Level1(ContentManager content)
        {
            FoodFight.mainPlayer = new Player(new ModelEntity(content.Load<Model>("Models\\corndog"), new Vector3(0, 40, 0), new Vector3(0.1f, 0.1f, 0.1f), 100.0f), content);
            ground = new ModelEntity(content.Load<Model>("Models\\playground"), new Vector3(0, -20, 0), new Vector3(5f, 1f, 5f), 0.0f);

            enemies = new List<Enemy>();
            rand = new Random();
            for (int i = 0; i < 100; i++)
            {
                enemies.Add(new Enemy(new ModelEntity(content.Load<Model>("Models\\corndog"), new Vector3(rand.Next(-1500, 3500), 40f, rand.Next(-3000, 2000)), new Vector3(0.1f, 0.1f, 0.1f), 100.0f)));
            }

            hudEntities = new List<Drawable>();
            ContentLoadUtility.LoadContent(content, "LoadFiles\\HUD.lfi", ref hudEntities);
        }

        public void Update(GameTime gameTime)
        {
            ground.Update();

            List<Enemy> deadEnemies = new List<Enemy>();

            foreach (Enemy e in enemies)
            {
                e.Update(gameTime);
                if(e.IsDead) {
                    deadEnemies.Add(e);
                }
            }

            foreach (Enemy e in deadEnemies)
            {
                enemies.Remove(e);
            }

            foreach (Drawable d in hudEntities)
            {
                d.Update();
            }

            if (Keyboard.GetState().IsKeyDown(Keys.Escape) && !FoodFight.GameStateManager.Contains(GameStates.Paused)
                && FoodFight.InputBindings.boardState.IsKeyDown(Keys.Escape) == false)
            {
                FoodFight.GameStateManager.Push(GameStates.Paused);
            }
        }

        public void Draw(SpriteBatch sBatch)
        {
            foreach (Drawable d in hudEntities)
            {
                d.Draw(sBatch);
            }
        }

        public void Render()
        {
            PlayerCamera cam = FoodFight.mainPlayer.Camera;
            ground.Draw(cam);

            foreach (Enemy e in enemies)
            {
                e.Draw(cam);
            }
        }
    }
}
