﻿#region Using Statements
using System;
using FoodFight._2D;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;
#endregion

namespace FoodFight
{
    public abstract class MenuItem
    {
        protected SpriteEntity _sprite;

        public SpriteEntity Sprite
        {
            get { return _sprite; }
        }

        public MenuItem(SpriteEntity sprite)
        {
            _sprite = sprite;
        }

        public virtual void Update(GameTime gameTime)
        {
        }
    }

    public class MenuBackground : MenuItem
    {
        public MenuBackground(SpriteEntity sprite)
            : base(sprite)
        {
            _sprite = sprite;
        }
    }

    public class NewGameOption : MenuItem
    {
        public NewGameOption(SpriteEntity sprite)
            : base(sprite)
        {
            _sprite = sprite;
        }

        public override void Update(GameTime gameTime)
        {
            _sprite.Rotation = (float)(Math.Sin(gameTime.TotalGameTime.TotalSeconds * 3) / 5);

            if(_sprite.BoundingBox.Contains(Mouse.GetState().X, Mouse.GetState().Y)
                && FoodFight.InputBindings.mouseState.LeftButton == ButtonState.Released
                && Mouse.GetState().LeftButton == ButtonState.Pressed)
            {
                FoodFight.GameStateManager.Push(GameStates.StartNewGame);
            }

            base.Update(gameTime);
        }
    }

    public class ExitGameOption : MenuItem
    {
        public ExitGameOption(SpriteEntity sprite)
            : base(sprite)
        {
            _sprite = sprite;
        }

        public override void Update(GameTime gameTime)
        {
            _sprite.Rotation = (float)(Math.Cos(gameTime.TotalGameTime.TotalSeconds)/3);

            if (_sprite.BoundingBox.Contains(Mouse.GetState().X, Mouse.GetState().Y)
                && FoodFight.InputBindings.mouseState.LeftButton == ButtonState.Released
                && Mouse.GetState().LeftButton == ButtonState.Pressed)
            {
                FoodFight.GameStateManager.Push(GameStates.RequestQuit);
            }
            base.Update(gameTime);
        }
    }

    public class RotatingArrowWidget : MenuItem
    {
        private Vector2 lastMousePos;

        public RotatingArrowWidget(SpriteEntity sprite)
            : base(sprite)
        {
            _sprite = sprite;
        }

        public override void Update(GameTime gameTime)
        {
            Vector2 mousePos = new Vector2(Mouse.GetState().X, Mouse.GetState().Y);
            Vector2 cornerPos = new Vector2(_sprite.Position.X - mousePos.X, _sprite.Position.Y - mousePos.Y);

            double theta;

            theta = Math.Tanh(cornerPos.X / cornerPos.Y);

            if (lastMousePos != mousePos)
            {
                _sprite.Rotation = MathHelper.ToRadians(90.0f) + (float)-theta;
            }

            lastMousePos = mousePos;

            base.Update(gameTime);
        }
    }
}
