﻿#region Using Statements
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;
#endregion

namespace FoodFight
{
    public class ModelEntity
    {
        private Model _model;
        public Vector3 Position { get; set; }
        public float Rotation { get; set; }
        public Vector3 Scale { get; set; }

        public ModelEntity(Model modelToLoad, Vector3 position, Vector3 scale)
        {
            _model = modelToLoad;
            this.Position = position;
            this.Scale = scale;
        }

        public void Update()
        {
            
        }

        public void Draw(PlayerCamera cam)
        {
            Matrix[] transforms = new Matrix[_model.Bones.Count];
            _model.CopyAbsoluteBoneTransformsTo(transforms);

            foreach(ModelMesh mesh in _model.Meshes) {
                foreach (BasicEffect effect in mesh.Effects)
                {
                    effect.EnableDefaultLighting();
                    effect.World = transforms[mesh.ParentBone.Index] * Matrix.CreateScale(this.Scale) * Matrix.CreateRotationY(this.Rotation) * Matrix.CreateTranslation(this.Position);
                    effect.View = Matrix.CreateLookAt(cam.Position, cam.LookAt, Vector3.Up);
                    effect.Projection = Matrix.CreatePerspectiveFieldOfView(MathHelper.ToRadians(45.0f), FoodFight.AspectRatio, 1.0f, 100000.0f);
                }

                mesh.Draw();
            }
        }
    }
}
